@@ -1,10 +1,9 @@
 from dataclasses import dataclass, field
-from functools import partial
 from pathlib import Path
 from typing import List
 
 from datagen.components.camera import Camera
-from datagen.components.datapoint.base import DataPoint
+from datagen.components.datapoint import DataPoint
 
 
 @dataclass
@@ -16,8 +15,10 @@ class Scene:
         self.cameras = self._init_cameras()
 
     def _init_cameras(self) -> List[Camera]:
-        camera = partial(Camera, scene_path=self.path)
-        return [camera(name=cam_dir.name) for cam_dir in sorted(self.path.iterdir()) if cam_dir.is_dir()]
+        return [Camera(name=camera_name, scene_path=self.path) for camera_name in self._get_cameras_names()]
+
+    def _get_cameras_names(self) -> List[str]:
+        return list(set(cam_dir.name for cam_dir in self.path.rglob("*camera*") if cam_dir.is_dir()))
 
     @property
     def datapoints(self) -> List[DataPoint]:
