@@ -10,4 +10,4 @@ class DatasetContainer(containers.DeclarativeContainer):
 
     sources_repository = providers.Singleton(SourcesRepository)
 
-    create = providers.Factory(Dataset, sources_repo=sources_repository)
+    create = providers.Factory(Dataset, config=config, sources_repo=sources_repository)
