@@ -1,6 +1,8 @@
 from abc import ABC, abstractmethod
 from enum import Enum
 
+from pathlib import Path
+
 
 class ImageFormat(Enum):
     PNG = "png"
@@ -8,7 +10,7 @@ class ImageFormat(Enum):
 
 
 class ImagingLibrary(ABC):
-    def read(self, image_file_path: str, **kwargs):
+    def read(self, image_file_path: Path, **kwargs):
         file_format = self._get_file_format(image_file_path)
         if file_format == ImageFormat.PNG.value:
             return self._read_png(image_file_path, kwargs)
@@ -18,13 +20,13 @@ class ImagingLibrary(ABC):
             raise ValueError(f"Unsupported image format: {file_format}")
 
     @staticmethod
-    def _get_file_format(image_file_path: str) -> str:
-        return image_file_path.split(".")[-1]
+    def _get_file_format(image_file_path: Path) -> str:
+        return image_file_path.suffix[1:]
 
     @abstractmethod
-    def _read_png(self, image_file_path: str, kwargs: dict):
+    def _read_png(self, image_file_path: Path, kwargs: dict):
         pass
 
     @abstractmethod
-    def _read_exr(self, image_file_path: str, kwargs: dict):
+    def _read_exr(self, image_file_path: Path, kwargs: dict):
         pass
